@@ -9,20 +9,25 @@
 #include "grantleetheme_debug.h"
 
 #include <QDebug>
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/safestring.h>
+#else
+#include <KTextTemplate/safestring.h>
+#endif
 
 #include <KLocalizedString>
 using namespace GrantleeTheme;
 
 GrantleeKi18nLocalizer::GrantleeKi18nLocalizer()
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : Grantlee::QtLocalizer()
+#else
+    : KTextTemplate::QtLocalizer()
+#endif
 {
 }
 
-GrantleeKi18nLocalizer::~GrantleeKi18nLocalizer()
-{
-}
+GrantleeKi18nLocalizer::~GrantleeKi18nLocalizer() = default;
 
 QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, const QVariantList &arguments) const
 {
@@ -51,10 +56,17 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, c
             str = str.subs(iter->toDouble());
             break;
         case QVariant::UserType:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             if (iter->canConvert<Grantlee::SafeString>()) {
                 str = str.subs(iter->value<Grantlee::SafeString>().get());
                 break;
             }
+#else
+            if (iter->canConvert<KTextTemplate::SafeString>()) {
+                str = str.subs(iter->value<KTextTemplate::SafeString>().get());
+                break;
+            }
+#endif
         // fall-through
         default:
             qCWarning(GRANTLEETHEME_LOG) << "Unknown type" << iter->typeName() << "(" << iter->type() << ")";
@@ -103,7 +115,11 @@ QString GrantleeKi18nLocalizer::localizeMonetaryValue(qreal value, const QString
 
 QString GrantleeKi18nLocalizer::currentLocale() const
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QString locale = Grantlee::QtLocalizer::currentLocale();
+#else
+    QString locale = KTextTemplate::QtLocalizer::currentLocale();
+#endif
     const int f = locale.indexOf(QLatin1Char('_'));
     if (f >= 0) {
         locale.truncate(f);
